.. figure::  https://i.pinimg.com/originals/bf/74/5c/bf745ca126c53b3fa562c189fd6a4b75.png

*Introducao* 

**Esta biblioteca é um orquestrador para a biblioeta Pyautomators, que paraleliza as execuções de pacotes de teste, afim de acelerar este processo.**

*Intalacao*

```
pip install orcautomators
```